package com.sun.org.glassfish.external.probe.provider;

import java.util.Iterator;
import java.util.Vector;

public class StatsProviderManager
{
    static StatsProviderManagerDelegate spmd;
    static Vector<StatsProviderInfo> toBeRegistered;
    
    private StatsProviderManager() {
    }
    
    public static boolean register(String configElement, PluginPoint pp, String subTreeRoot, Object statsProvider) {
        return register(pp, configElement, subTreeRoot, statsProvider, null);
    }
    
    public static boolean register(PluginPoint pp, String configElement, String subTreeRoot, Object statsProvider, String invokerId) {
        StatsProviderInfo spInfo = new StatsProviderInfo(configElement, pp, subTreeRoot, statsProvider, invokerId);
        return registerStatsProvider(spInfo);
    }
    
    public static boolean register(String configElement, PluginPoint pp, String subTreeRoot, Object statsProvider, String configLevelStr) {
        return register(configElement, pp, subTreeRoot, statsProvider, configLevelStr, null);
    }
    
    public static boolean register(String configElement, PluginPoint pp, String subTreeRoot, Object statsProvider, String configLevelStr, String invokerId) {
        StatsProviderInfo spInfo = new StatsProviderInfo(configElement, pp, subTreeRoot, statsProvider, invokerId);
        spInfo.setConfigLevel(configLevelStr);
        return registerStatsProvider(spInfo);
    }
    
    private static boolean registerStatsProvider(StatsProviderInfo spInfo) {
        if (StatsProviderManager.spmd == null) {
            StatsProviderManager.toBeRegistered.add(spInfo);
            return false;
        }
        StatsProviderManager.spmd.register(spInfo);
        return true;
    }
    
    public static boolean unregister(Object statsProvider) {
        if (StatsProviderManager.spmd == null) {
            for (StatsProviderInfo spInfo : StatsProviderManager.toBeRegistered) {
                if (spInfo.getStatsProvider() == statsProvider) {
                    StatsProviderManager.toBeRegistered.remove(spInfo);
                    break;
                }
                continue;
            }
            return false;
        }
        StatsProviderManager.spmd.unregister(statsProvider);
        return true;
    }
    
    public static boolean hasListeners(String probeStr) {
        return StatsProviderManager.spmd != null && StatsProviderManager.spmd.hasListeners(probeStr);
    }
    
    public static void setStatsProviderManagerDelegate(StatsProviderManagerDelegate lspmd) {
        if (lspmd == null) {
            return;
        }
        StatsProviderManager.spmd = lspmd;
        for (StatsProviderInfo spInfo : StatsProviderManager.toBeRegistered) {
            StatsProviderManager.spmd.register(spInfo);
        }
        StatsProviderManager.toBeRegistered.clear();
        return;
    }
    
    static {
        StatsProviderManager.toBeRegistered = new Vector();
    }
}
